==> haskell-warp-tls-3.2.4.3-67-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.4.3
id: warp-tls-3.2.4.3-7DqjOSs6LbuJQbXD9wbsHu
key: warp-tls-3.2.4.3-7DqjOSs6LbuJQbXD9wbsHu
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: 0e066e4fb87e808bf9675941d743a1bd
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.4.3/site-local/warp-tls-3.2.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/warp-tls-3.2.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/warp-tls-3.2.4.3
hs-libraries: HSwarp-tls-3.2.4.3-7DqjOSs6LbuJQbXD9wbsHu
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
    streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    tls-1.4.1-F3t7z6RRnviKSY4wF5XnZC
    tls-session-manager-0.0.0.2-5vSKayRLZwU8BNSU2XK0FT
    wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
    warp-3.2.23-IWiWJvudCGxJ1ocDsVuKFW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             tls-1.4.1-F3t7z6RRnviKSY4wF5XnZC=06efd5e8bfabe9f3899ca45089f0d989
             tls-session-manager-0.0.0.2-5vSKayRLZwU8BNSU2XK0FT=e0127382b520e040e3b3d2da52c5349e
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
             warp-3.2.23-IWiWJvudCGxJ1ocDsVuKFW=31d1d20026b0e4505213bb0775d373d4
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.4.3-73-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.4.3
id: warp-tls-3.2.4.3-7oeM8RGAuIfB63hp6mBrtW
key: warp-tls-3.2.4.3-7oeM8RGAuIfB63hp6mBrtW
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: 2d84be199af0fe736672d7bc292bec9e
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.4.3/site-local/warp-tls-3.2.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/warp-tls-3.2.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/warp-tls-3.2.4.3
hs-libraries: HSwarp-tls-3.2.4.3-7oeM8RGAuIfB63hp6mBrtW
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
    streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    tls-1.4.1-5itJXVDmFQM8ghL7OHqA9s
    tls-session-manager-0.0.0.2-E0SsDRKrWGdJD4nrRBnXYa
    wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
    warp-3.2.23-K9auRtl2jUQ3NPlKX6CVYn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             tls-1.4.1-5itJXVDmFQM8ghL7OHqA9s=ddb930e888bbc4345649b0ea4c3889fd
             tls-session-manager-0.0.0.2-E0SsDRKrWGdJD4nrRBnXYa=f84b5778646c0995875d3d58b0c1a3e5
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
             warp-3.2.23-K9auRtl2jUQ3NPlKX6CVYn=a0c1704313586045c2e04a82fefd7cc6
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
